==> haskell-math-functions-0.3.4.2-224-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-math-functions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 math-functions
version:              0.3.4.2
visibility:           public
id:                   math-functions-0.3.4.2-IFVTlaeMmkdJp5Q539cuzB
key:                  math-functions-0.3.4.2-IFVTlaeMmkdJp5Q539cuzB
license:              BSD-2-Clause
maintainer:           Alexey Khudyakov <alexey.skladnoy@gmail.com>
author:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Alexey Khudyakov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/bos/math-functions
synopsis:             Collection of tools for numeric computations
description:
    This library contain collection of various utilities for numerical
    computing. So far there'\''re special mathematical functions,
    compensated summation algorithm, summation of series, root finding
    for real functions, polynomial summation and Chebyshev
    polynomials.

category:             Math, Numeric
abi:                  f644239d2037f53aee40973320bb39b5
exposed:              True
exposed-modules:
    Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
    Numeric.Polynomial Numeric.Polynomial.Chebyshev Numeric.RootFinding
    Numeric.Series Numeric.SpecFunctions Numeric.SpecFunctions.Extra
    Numeric.SpecFunctions.Internal Numeric.Sum

hidden-modules:       Numeric.SpecFunctions.Compat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/math-functions-0.3.4.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/math-functions-0.3.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-math-functions
hs-libraries:         HSmath-functions-0.3.4.2-IFVTlaeMmkdJp5Q539cuzB
depends:
    base-4.15.1.0 data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO
    deepseq-1.4.5.0 primitive-0.7.4.0-A5hJyO7gfJjKCazGezxOm3
    vector-0.13.0.0-FO1psvzIWe996069p2V3EL

haddock-interfaces:
    /usr/share/doc/haskell-math-functions/html/math-functions.haddock

haddock-html:         /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-math-functions-0.3.4.2-236-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-math-functions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 math-functions
version:              0.3.4.2
visibility:           public
id:                   math-functions-0.3.4.2-gWbWHW2mmHH9kXahLfPMH
key:                  math-functions-0.3.4.2-gWbWHW2mmHH9kXahLfPMH
license:              BSD-2-Clause
maintainer:           Alexey Khudyakov <alexey.skladnoy@gmail.com>
author:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Alexey Khudyakov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/bos/math-functions
synopsis:             Collection of tools for numeric computations
description:
    This library contain collection of various utilities for numerical
    computing. So far there'\''re special mathematical functions,
    compensated summation algorithm, summation of series, root finding
    for real functions, polynomial summation and Chebyshev
    polynomials.

category:             Math, Numeric
abi:                  e4e5b973b8f53cc8793c4c22462e7adb
exposed:              True
exposed-modules:
    Numeric.MathFunctions.Comparison Numeric.MathFunctions.Constants
    Numeric.Polynomial Numeric.Polynomial.Chebyshev Numeric.RootFinding
    Numeric.Series Numeric.SpecFunctions Numeric.SpecFunctions.Extra
    Numeric.SpecFunctions.Internal Numeric.Sum

hidden-modules:       Numeric.SpecFunctions.Compat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/math-functions-0.3.4.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/math-functions-0.3.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-math-functions
hs-libraries:         HSmath-functions-0.3.4.2-gWbWHW2mmHH9kXahLfPMH
depends:
    base-4.15.1.0 data-default-class-0.1.2.0-IxhEAzgy8931aXcEiJcyZO
    deepseq-1.4.5.0 primitive-0.7.4.0-4igQPjVFZ0u45ZZpSLQSLc
    vector-0.13.0.0-CBdHfq8cDb33l37FQ8xap7

haddock-interfaces:
    /usr/share/doc/haskell-math-functions/html/math-functions.haddock

haddock-html:         /usr/share/doc/haskell-math-functions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
